@@ -278,6 +278,7 @@ typedef struct _v4l2_dev_sys_data_t {
   int current;
   uint64_t busnum;
   uint64_t devnum;
+  uint32_t device_caps;
 } v4l2_dev_sys_data_t;
 
 /* v4l2 device handler - opaque data structure*/
@@ -1318,6 +1319,34 @@ uint8_t v4l2core_get_h264_spatial_scale_mode(v4l2_dev_t *vd, uint8_t query);
  */
 int v4l2core_set_h264_spatial_scale_mode(v4l2_dev_t *vd, uint8_t mode);
 
+/*
+ *  ######### Meet4K ##########
+ */
+
+/*
+ * get meet4k main unit id
+ * args:
+ *   vd - pointer to v4l2 device handler
+ *
+ * asserts:
+ *   vd is not null
+ *
+ * returns: unit id on success or error code ( < 0 ) on fail
+ */
+uint8_t get_uvc_meet4k_unit_id (v4l2_dev_t *vd);
+
+/*
+ * get meet4k secondary unit id
+ * args:
+ *   vd - pointer to v4l2 device handler
+ *
+ * asserts:
+ *   vd is not null
+ *
+ * returns: unit id on success or error code ( < 0 ) on fail
+ */
+uint8_t get_uvc_meet4k_unit_id2 (v4l2_dev_t *vd);
+
 /*
  *  ######### XU CONTROLS ##########
  */
